@@ -1,7 +1,7 @@
 package Net::Stripe;
-$Net::Stripe::VERSION = '0.40_002'; # TRIAL
+$Net::Stripe::VERSION = '0.40_003'; # TRIAL
 
-$Net::Stripe::VERSION = '0.40002';use Moose;
+$Net::Stripe::VERSION = '0.40003';use Moose;
 use Class::Load;
 use Type::Tiny 1.008004;
 use Kavorka;
@@ -18,6 +18,7 @@ use Net::Stripe::Invoice;
 use Net::Stripe::Card;
 use Net::Stripe::Source;
 use Net::Stripe::Plan;
+use Net::Stripe::Product;
 use Net::Stripe::Coupon;
 use Net::Stripe::Charge;
 use Net::Stripe::Customer;
@@ -141,13 +142,14 @@ Charges: {
             $customer = $customer->id;
         }
         my %args = (
+            path => 'charges',
             created => $created,
             customer => $customer,
             ending_before => $ending_before,
             limit => $limit,
             starting_after => $starting_after,
         );
-        $self->_get('charges', \%args);
+        $self->_get_all(%args);
     }
 
     method capture_charge(
@@ -179,6 +181,7 @@ BalanceTransactions: {
 Customers: {
     method post_customer(Net::Stripe::Customer|StripeCustomerId :$customer?,
                          Int :$account_balance?,
+                         Int :$balance?,
                          Net::Stripe::Token|StripeTokenId :$card?,
                          Str :$coupon?,
                          Str :$default_card?,
@@ -197,6 +200,7 @@ Customers: {
         } else {
             my %args = (
                 account_balance => $account_balance,
+                balance => $balance,
                 card => $card,
                 coupon => $coupon,
                 default_card => $default_card,
@@ -228,11 +232,12 @@ Customers: {
             $customer = $customer->id;
         }
         my %args = (
+            path => "customers/$customer/subscriptions",
             ending_before => $ending_before,
             limit => $limit,
             starting_after => $starting_after,
         );
-        return $self->_get("customers/$customer/subscriptions", \%args);
+        return $self->_get_all(%args);
     }
 
     method get_customer(Str :$customer_id) {
@@ -248,13 +253,14 @@ Customers: {
 
     method get_customers(HashRef :$created?, Str :$ending_before?, Int :$limit?, Str :$starting_after?, Str :$email?) {
         my %args = (
+            path => 'customers',
             created => $created,
             ending_before => $ending_before,
             limit => $limit,
             starting_after => $starting_after,
             email => $email,
         );
-        $self->_get('customers', \%args);
+        $self->_get_all(%args);
     }
 }
 
@@ -278,13 +284,14 @@ Cards: {
         }
 
         my %args = (
+            path => "customers/$customer/sources",
             object => "card",
             created => $created,
             ending_before => $ending_before,
             limit => $limit,
             starting_after => $starting_after,
         );
-        $self->_get("customers/$customer/sources", \%args);
+        $self->_get_all(%args);
     }
 
     method post_card(
@@ -467,7 +474,8 @@ Subscriptions: {
                              Net::Stripe::Card|Net::Stripe::Token|Str :$source?,
                              Int :$quantity? where { $_ >= 0 },
                              Num :$application_fee_percent?,
-                             Bool :$prorate? = 1
+                             Bool :$prorate? = 1,
+                             Bool :$cancel_at_period_end?,
                          ) {
         if (ref($customer)) {
             $customer = $customer->id;
@@ -485,7 +493,8 @@ Subscriptions: {
                         source => $source,
                         prorate => $prorate,
                         quantity => $quantity,
-                        application_fee_percent => $application_fee_percent);
+                        application_fee_percent => $application_fee_percent,
+                        cancel_at_period_end => $cancel_at_period_end);
             if (defined($subscription)) {
                 $args{id} = $subscription;
             }
@@ -524,6 +533,122 @@ Tokens: {
 }
 
 
+Products: {
+    method create_product(
+        Str :$name!,
+        Bool :$active?,
+        ArrayRef[Str] :$attributes?,
+        Str :$caption?,
+        ArrayRef[Str] :$deactivate_on?,
+        Str :$description?,
+        StripeProductId|Str :$id?,
+        ArrayRef[Str] :$images?,
+        HashRef[Str] :$metadata?,
+        HashRef[Num] :$package_dimensions?,
+        Bool :$shippable?,
+        Str :$statement_descriptor?,
+        StripeProductType :$type?,
+        Str :$unit_label?,
+        Str :$url?,
+    ) {
+        my %args = (
+            name => $name,
+            active => $active,
+            attributes => $attributes,
+            caption => $caption,
+            deactivate_on => $deactivate_on,
+            description => $description,
+            id => $id,
+            images => $images,
+            metadata => $metadata,
+            package_dimensions => $package_dimensions,
+            shippable => $shippable,
+            statement_descriptor => $statement_descriptor,
+            type => $type,
+            unit_label => $unit_label,
+            url => $url,
+        );
+        my $product_obj = Net::Stripe::Product->new( %args );
+        return $self->_post('products', $product_obj);
+    }
+
+    method get_product(
+        StripeProductId|Str :$product_id!,
+    ) {
+        return $self->_get("products/$product_id");
+    }
+
+    method update_product(
+        StripeProductId|Str :$product_id!,
+        Bool :$active?,
+        ArrayRef[Str] :$attributes?,
+        Str :$caption?,
+        ArrayRef[Str] :$deactivate_on?,
+        Str :$description?,
+        ArrayRef[Str] :$images?,
+        HashRef[Str]|EmptyStr :$metadata?,
+        Str :$name?,
+        HashRef[Num] :$package_dimensions?,
+        Bool :$shippable?,
+        Str :$statement_descriptor?,
+        StripeProductType :$type?,
+        Str :$unit_label?,
+        Str :$url?,
+    ) {
+        my %args = (
+            active => $active,
+            attributes => $attributes,
+            caption => $caption,
+            deactivate_on => $deactivate_on,
+            description => $description,
+            images => $images,
+            metadata => $metadata,
+            name => $name,
+            package_dimensions => $package_dimensions,
+            shippable => $shippable,
+            statement_descriptor => $statement_descriptor,
+            type => $type,
+            unit_label => $unit_label,
+            url => $url,
+        );
+        my $product_obj = Net::Stripe::Product->new( %args );
+        return $self->_post("products/$product_id", $product_obj);
+    }
+
+    method list_products(
+        Bool :$active?,
+        ArrayRef[StripeProductId|Str] :$ids,
+        Bool :$shippable?,
+        StripeProductType :$type?,
+        Str :$url?,
+        HashRef[Str] :$created?,
+        Str :$ending_before?,
+        Int :$limit?,
+        Str :$starting_after?,
+    ) {
+        my %args = (
+            path => "products",
+            active => _encode_boolean( $active ),
+            ids => $ids,
+            shippable => _encode_boolean( $shippable ),
+            type => $type,
+            url => $url,
+            created => $created,
+            ending_before => $ending_before,
+            limit => $limit,
+            starting_after => $starting_after,
+        );
+        return $self->_get_all( %args );
+    }
+
+    method delete_product(
+        StripeProductId|Str :$product_id!,
+    ) {
+        $self->_delete("products/$product_id");
+    }
+}
+
+
 Plans: {
     method post_plan(Str :$id,
                      Int :$amount,
@@ -531,6 +656,7 @@ Plans: {
                      Str :$interval,
                      Int :$interval_count?,
                      Str :$name,
+                     StripeProductId|Str :$product,
                      Int :$trial_period_days?,
                      HashRef :$metadata?,
                      Str :$statement_descriptor?) {
@@ -540,6 +666,7 @@ Plans: {
                                           interval => $interval,
                                           interval_count => $interval_count,
                                           name => $name,
+                                          product => $product,
                                           trial_period_days => $trial_period_days,
                                           metadata => $metadata,
                                           statement_descriptor => $statement_descriptor);
@@ -557,13 +684,20 @@ Plans: {
         $self->_delete("plans/$plan");
     }
 
-    method get_plans(Str :$ending_before?, Int :$limit?, Str :$starting_after?) {
+    method get_plans(
+        StripeProductId|Str :$product?,
+        Str :$ending_before?,
+        Int :$limit?,
+        Str :$starting_after?,
+    ) {
         my %args = (
+            path => 'plans',
+            product => $product,
             ending_before => $ending_before,
             limit => $limit,
             starting_after => $starting_after,
         );
-        $self->_get('plans', \%args);
+        $self->_get_all(%args);
     }
 }
 
@@ -603,11 +737,12 @@ Coupons: {
 
     method get_coupons(Str :$ending_before?, Int :$limit?, Str :$starting_after?) {
         my %args = (
+            path => 'coupons',
             ending_before => $ending_before,
             limit => $limit,
             starting_after => $starting_after,
         );
-        $self->_get('coupons', \%args);
+        $self->_get_all(%args);
     }
 }
 
@@ -629,7 +764,8 @@ Invoices: {
                           Int :$application_fee?,
                           Str :$description?,
                           HashRef :$metadata?,
-                          Net::Stripe::Subscription|Str :$subscription?) {
+                          Net::Stripe::Subscription|Str :$subscription?,
+                          Bool :$auto_advance?) {
         if (ref($customer)) {
             $customer = $customer->id;
         }
@@ -644,7 +780,8 @@ Invoices: {
                                 application_fee => $application_fee,
                                 description => $description,
                                 metadata => $metadata,
-                                subscription =>$subscription
+                                subscription => $subscription,
+                                auto_advance => $auto_advance,
                             });
     }
 
@@ -652,6 +789,7 @@ Invoices: {
     method post_invoice(Net::Stripe::Invoice|Str :$invoice,
                         Int :$application_fee?,
                         Bool :$closed?,
+                        Bool :$auto_advance?,
                         Str :$description?,
                         HashRef :$metadata?) {
         if (ref($invoice)) {
@@ -662,6 +800,7 @@ Invoices: {
                             {
                                 application_fee => $application_fee,
                                 closed => $closed,
+                                auto_advance => $auto_advance,
                                 description => $description,
                                 metadata => $metadata
                             });
@@ -699,9 +838,10 @@ Invoices: {
             $customer = $customer->id;
         }
         my %args = (
+            path => 'invoices/upcoming',
             customer => $customer,
         );
-        return $self->_get("invoices/upcoming", \%args);
+        return $self->_get_all(%args);
     }
 }
 
@@ -778,12 +918,13 @@ InvoiceItems: {
             $customer = $customer->id;
         }
         my %args = (
+            path => 'invoiceitems',
             created => $created,
             ending_before => $ending_before,
             limit => $limit,
             starting_after => $starting_after,
         );
-        $self->_get('invoiceitems', \%args);
+        $self->_get_all(%args);
     }
 }
 
@@ -825,6 +966,8 @@ sub convert_to_form_fields {
                 foreach my $fn (keys %{$hash->{$key}}) {
                     $r->{$key . '[' . $fn . ']'} = $hash->{$key}->{$fn};
                 }
+            } elsif (ref($hash->{$key}) eq 'ARRAY') {
+                $r->{$key . '[]'} = $hash->{$key};
             } else {
                 $r->{$key} = $hash->{$key};
             }
@@ -922,6 +1065,9 @@ sub _hash_to_object {
     # coerce post-2015-02-18 source-type args to to card-type args
     $hash = _post_2015_02_18_processing( $hash );
 
+    # coerce post-2019-10-17 balance to account_balance
+    $hash = _post_2019_10_17_processing( $hash );
+
     foreach my $k (grep { ref($hash->{$_}) } keys %$hash) {
         my $v = $hash->{$k};
         if (ref($v) eq 'HASH' && defined($v->{object})) {
@@ -1102,6 +1248,87 @@ sub _post_2015_02_18_processing {
     return $hash;
 }
 
+# coerce post-2019-10-17 balance to account_balance
+fun _post_2019_10_17_processing(
+    HashRef $hash,
+) {
+    if ( exists( $hash->{object} ) && $hash->{object} eq 'customer' ) {
+        if ( ! exists( $hash->{account_balance} ) && exists( $hash->{balance} ) ) {
+            $hash->{account_balance} = $hash->{balance};
+        }
+    }
+    return $hash;
+}
+
+method _get_all(
+    Str :$path!,
+    Maybe[Str] :$ending_before?,
+    Maybe[Int] :$limit?,
+    Maybe[Str] :$starting_after?,
+    %object_filters,
+) {
+
+    # minimize the number of API calls by retrieving as many results as
+    # possible per call. the API currently returns a maximum of 100 results.
+    my $API_PAGE_SIZE = 100;
+    my $PAGE_SIZE = $limit;
+    my $GET_MORE;
+    if ( defined( $limit ) && ( $limit eq '0' || $limit > $API_PAGE_SIZE ) ) {
+        $PAGE_SIZE = $API_PAGE_SIZE;
+        $GET_MORE = 1;
+    }
+
+    my %args = (
+        %object_filters,
+        ending_before => $ending_before,
+        limit => $PAGE_SIZE,
+        starting_after => $starting_after,
+    );
+    my $list = $self->_get($path, \%args);
+
+    if ( $GET_MORE ) {
+        # passing 'ending_before' causes the API to start with the oldest
+        # records. so in order to always provide records in reverse-chronological
+        # order, we must prepend these to the existing records.
+        my $REVERSE = defined( $ending_before ) && ! defined( $starting_after );
+        my $MAX_COUNT = $limit eq '0' ? undef : $limit;
+        while ( 1 ) {
+            my $PAGE_SIZE = $API_PAGE_SIZE;
+            if ( defined( $MAX_COUNT ) ) {
+                my $TO_FETCH = $MAX_COUNT - scalar( $list->elements );
+                last if $TO_FETCH <= 0;
+                $PAGE_SIZE = $TO_FETCH if $TO_FETCH < $PAGE_SIZE;
+            }
+
+            my %args = (
+                %object_filters,
+                limit => $PAGE_SIZE,
+                ( $REVERSE ? $list->_previous_page_args() : $list->_next_page_args() ),
+            );
+            my $page = $self->_get($path, \%args);
+
+            last if $page->is_empty;
+
+            $list = Net::Stripe::List::_merge_lists(
+                lists => [ $REVERSE ?
+                    ( $page, $list ) :
+                    ( $list, $page )
+                ],
+            );
+        }
+    }
+    return $list;
+}
+
+fun _encode_boolean(
+    Bool $value!,
+) {
+    # a bare `return` with no arguemnts evaluates to an empty list, resulting
+    # in 'odd number of elements in hash assignment, so we must return undef
+    return undef unless defined( $value );
+    return $value ? 'true' : 'false';
+}
+
 method _build_api_base { 'https://api.stripe.com/v1' }
 
 method _build_ua {
@@ -1124,7 +1351,7 @@ Net::Stripe - API client for Stripe.com
 
 =head1 VERSION
 
-version 0.40_002
+version 0.40_003
 
 =head1 SYNOPSIS
 
@@ -1379,6 +1606,8 @@ L<https://stripe.com/docs/api/customers/update#update_customer>
 
 =item * account_balance - Int, optional
 
+=item * balance - Int, optional
+
 =item * card - L<Net::Stripe::Token> or StripeTokenId, default card for the customer, optional
 
 =item * source - StripeTokenId or StripeSourceId, source for the customer, optional
@@ -1789,9 +2018,11 @@ L<https://stripe.com/docs/api#create_subscription>
 
 =item * prorate - Bool, optional
 
+=item * cancel_at_period_end - Bool, optional
+
 =back
 
-Returns a L<Net::Stripe::Customer> object.
+Returns a L<Net::Stripe::Subscription> object.
 
   $stripe->post_subscription(customer => $customer, plan => 'testplan');
 
@@ -1847,6 +2078,182 @@ Returns a L<Net::Stripe::Token>.
 
   $stripe->get_token(token_id => 'testtokenid');
 
+=head1 Product Methods
+
+=head2 create_product
+
+Create a new Product
+
+L<https://stripe.com/docs/api/products/create#create_product>
+L<https://stripe.com/docs/api/service_products/create#create_service_product>
+
+=over
+
+=item * name - Str - name of the product - required
+
+=item * active - Bool - whether the product is currently available for purchase
+
+=item * attributes - ArrayRef[Str] - a list of attributes that each sku can provide values for
+
+=item * caption - Str - a short description
+
+=item * deactivate_on - ArrayRef[Str] - an list of connect application identifiers that cannot purchase this product
+
+=item * description - Str - description
+
+=item * id - Str - unique identifier
+
+=item * images - ArrayRef[Str] - a list of image URLs
+
+=item * metadata - HashRef[Str] - metadata
+
+=item * package_dimensions - HashRef - package dimensions for shipping
+
+=item * shippable - Bool - whether the product is a shipped good
+
+=item * statement_descriptor - Str - descriptor for statement
+
+=item * type - StripeProductType - the type of the product
+
+=item * unit_label - Str - label that represents units of the product
+
+=item * url - Str - URL of a publicly-accessible web page for the product
+
+=back
+
+Returns a L<Net::Stripe::Product>
+
+  $stripe->create_product(
+      name => $product_name,
+      type => 'good',
+  );
+
+=head2 get_product
+
+Retrieve an existing Product
+
+L<https://stripe.com/docs/api/products/retrieve#retrieve_product>
+L<https://stripe.com/docs/api/service_products/retrieve#retrieve_service_product>
+
+=over
+
+=item * product_id - StripeProductId|Str - id of product to retrieve - required
+
+=back
+
+Returns a L<Net::Stripe::Product>
+
+  $stripe->get_product(
+      product_id => $product_id,
+  );
+
+=head2 update_product
+
+Update an existing Product
+
+L<https://stripe.com/docs/api/products/update#update_product>
+L<https://stripe.com/docs/api/service_products/update#update_service_product>
+
+=over
+
+=item * product_id - StripeProductId|Str - id of product to retrieve - required
+
+=item * active - Bool - whether the product is currently available for purchase
+
+=item * attributes - ArrayRef[Str] - a list of attributes that each sku can provide values for
+
+=item * caption - Str - a short description
+
+=item * deactivate_on - ArrayRef[Str] - an list of connect application identifiers that cannot purchase this product
+
+=item * description - Str - description
+
+=item * images - ArrayRef[Str] - a list of image URLs
+
+=item * metadata - HashRef[Str] - metadata
+
+=item * name - Str - name of the product
+
+=item * package_dimensions - HashRef - package dimensions for shipping
+
+=item * shippable - Bool - whether the product is a shipped good
+
+=item * statement_descriptor - Str - descriptor for statement
+
+=item * type - StripeProductType - the type of the product
+
+=item * unit_label - Str - label that represents units of the product
+
+=item * url - Str - URL of a publicly-accessible web page for the product
+
+=back
+
+Returns a L<Net::Stripe::Product>
+
+  $stripe->update_product(
+      product_id => $product_id,
+      name => $new_name,
+  );
+
+=head2 list_products
+
+Retrieve a list of Products
+
+L<https://stripe.com/docs/api/products/list#list_products>
+L<https://stripe.com/docs/api/service_products/list#list_service_products>
+
+=over
+
+=item * active - Bool - only return products that are active or inactive
+
+=item * ids - StripeProductId|Str - only return products with the given ids
+
+=item * shippable - Bool - only return products that can or cannot be shipped
+
+=item * url - Str - only return products with the given url
+
+=item * type - StripeProductType - only return products of this type
+
+=item * created - HashRef[Str] - created conditions to match
+
+=item * ending_before - Str - ending before condition
+
+=item * limit - Int - maximum number of objects to return
+
+=item * starting_after - Str - starting after condition
+
+=back
+
+Returns a L<Net::Stripe::List> object containing L<Net::Stripe::Product> objects.
+
+  $stripe->list_products(
+      limit => 5,
+  );
+
+=head2 delete_product
+
+Delete an existing Product
+
+L<https://stripe.com/docs/api/products/delete#delete_product>
+L<https://stripe.com/docs/api/service_products/delete#delete_service_product>
+
+=over
+
+=item * product_id - StripeProductId|Str - id of product to delete - required
+
+=back
+
+Returns hashref of the form
+
+  {
+    deleted => <bool>,
+    id => <product_id>,
+  }
+
+  $stripe->delete_product(
+      product_id => $product_id,
+  );
+
 =head1 Plan Methods
 
 =head2 post_plan
@@ -1925,6 +2332,8 @@ L<https://stripe.com/docs/api#list_plans>
 
 =over
 
+=item * product - StripeProductId|Str - only return plans for the given product
+
 =item * ending_before - Str, optional
 
 =item * limit - Int, optional
@@ -2137,7 +2546,7 @@ Returns a L<Net::Stripe::Invoice>.
 
 =over
 
-=item * customer, L<Net::Stripe::Cusotmer> or Str
+=item * customer, L<Net::Stripe::Customer> or Str
 
 =back
 
@@ -2306,6 +2715,67 @@ object is serialized in the POST stream, and it appears that you are requesting
 to set default_card to the id of a card that no longer exists, but rather
 is being replaced by the new value of the card attribute in the object.
 
+=item Plan objects now linked to Product objects
+
+For Stripe API versions after 2018-02-15 L<https://stripe.com/docs/upgrades#2018-02-05>
+each Plan object is linked to a Product object with type=service. The
+Plan object 'name' and 'statement_descriptor' attributes have been moved to
+Product objects.
+
+=back
+
+=head3 DEPRECATION WARNING
+
+=over
+
+=item update 'card' to 'source' for Charge and Customer
+
+While the API returns both card-related and source-related values for earlier
+versions, making the update mostly backwards-compatible, Stripe API versions
+after 2015-02-18 L<https://stripe.com/docs/upgrades#2015-02-18> will no longer
+return the card-related values, so you should update your code where necessary
+to use the 'source' argument and method for Charge objects, and the 'source',
+'sources' and 'default_source' arguments and methods for Customer, in
+preparation for the eventual deprecation of the card-related arguments.
+
+=item update 'account_balance' to 'balance' for Customer
+
+While the API returns both 'account_balance' and 'balance' for earlier
+versions, making the update backwards-compatible, Stripe API versions
+after 2019-10-17 L<https://stripe.com/docs/upgrades#2019-10-17> do not
+accept or return 'account_balance', so you should update your code where
+necessary to use the 'balance' argument and method for Customer objects in
+preparation for the eventual deprecation of the 'account_balance' argument.
+
+=item use 'cancel_at_period_end' instead of 'at_period_end' for canceling Subscriptions
+
+For Stripe API versions after 2018-08-23
+L<https://stripe.com/docs/upgrades#2018-08-23>, you can no longer use
+'at_period_end' in delete_subscription(). The delete_subscription() method
+is reserved for immediate canceling going forward. You should update your
+code to use 'cancel_at_period_end in update_subscription() instead.
+
+=item update 'date' to 'created' for Invoice
+
+While the API returns both 'date' and 'created' for earlier versions, making
+the update backwards-compatible, Stripe API versions after 2019-03-14
+L<https://stripe.com/docs/upgrades#2019-03-14> only return 'created', so you
+should update your code where necessary to use the 'created' method for
+Invoice objects in preparation for the eventual deprecation of the 'date'
+argument.
+
+=item use 'auto_advance' instead of 'closed' for Invoice
+
+The 'closed' attribute for the Invoice object controls automatic collection,
+and has been deprecated in favor of the more specific 'auto_advance' attribute.
+Where you might have set closed=true on Invoices in the past, set
+auto_advance=false. While the API returns both 'closed' and 'auto_advance'
+for earlier versions, making the update backwards-compatible, Stripe API
+versions after 2018-11-08 L<https://stripe.com/docs/upgrades#2018-11-08>
+only return 'auto_advance', so you should update your code where necessary to
+use the 'auto_advance' argument and method for Invoice objects in preparation
+for the eventual deprecation of the 'closed' argument.
+
 =back
 
 =head3 BUG FIXES
@@ -2372,11 +2842,6 @@ which is the format that C<Net::Stripe::List> expects. This makes the SDK
 compatible with the Stripe API back to the earliest documented API version
 L<https://stripe.com/docs/upgrades#2011-06-21>.
 
-=item add update_card()
-
-This method allows updates to card address, expiration, metadata, etc for
-existing customer cards.
-
 =item encode card metdata in convert_to_form_fields()
 
 When passing a hashref with a nested metadata hashref to _post(), that
@@ -2404,6 +2869,19 @@ convert_to_form_fields(), _get() can now easily handle the same calling
 form as _post(), eliminating the need for _get_collections() and
 _get_with_args(). We have also updated _delete() accordingly.
 
+=item add _get_all()
+
+Similar to methods provided by other SDKs, calls using this method will allow
+access to all records for a given object type without having to manually
+paginate through the results. It is not intended to be used directly, but
+will be accessed through new and existing list-retrieval methods. In order to
+maintain backwards-compatibility with existing list retrieval behavior, this
+method supports passing a value of 0 for 'limit' in order to retrieve all
+records. Any other positive integer value for 'limit' will attempt to retrieve
+that number of records up to the maximum available. As before, not passing a
+value for 'limit', or explicitly passing an undefined value, retrieves whatever
+number of records the API returns by default.
+
 =back
 
 =head3 UPDATES
@@ -2428,6 +2906,11 @@ if your account is using Stripe API version 2015-02-18 or later, you should
 update any code that relies on strict checking of the return value of
 Charge->status.
 
+=item add update_card()
+
+This method allows updates to card address, expiration, metadata, etc for
+existing customer cards.
+
 =item update Token attributes
 
 Added type and client_ip attributes for L<Net::Stripe::Token>.
@@ -2439,6 +2922,33 @@ Per the API, any remaining amount is immediately refunded. The charge object
 now also has a 'refunds' attribute, representing a L<Net::Stripe::List>
 of L<Net::Stripe::Refund> objects for the charge.
 
+=item add Source
+
+Added a Source object. Also added 'source' attribute and argument for Charge
+objects and methods, and added 'source', 'sources' and 'default_source'
+attributes and arguments for Customer objects and methods.
+
+=item add balance for Customer
+
+Added 'balance' attribute and arguments for Customer objects and methods.
+
+=item add cancel_at_period_end for update_subscription()
+
+Added 'cancel_at_period_end' argument update_subscription() and added
+'cancel_at_period_end' to the POST stream for Subscription objects.
+
+=item update Invoice
+
+Added 'created' attribute for Invoice objects, and removed the required
+constraint for the deprecated 'date' attribute. Also added the 'auto_advance'
+attribute and removed the required constraint for the deprecated 'closed'
+attribute.
+
+=item add Product
+
+Added a Product object. Also added 'product' attribute and argument for Plan
+objects and methods.
+
 =back
 
 =head1 SEE ALSO
