@@ -1,7 +1,7 @@
 package Net::Stripe::Customer;
-$Net::Stripe::Customer::VERSION = '0.40_002'; # TRIAL
+$Net::Stripe::Customer::VERSION = '0.40_003'; # TRIAL
 
-$Net::Stripe::Customer::VERSION = '0.40002';use Moose;
+$Net::Stripe::Customer::VERSION = '0.40003';use Moose;
 use Kavorka;
 use Net::Stripe::Plan;
 use Net::Stripe::Token;
@@ -23,7 +23,8 @@ has 'plan'        => (is => 'rw', isa => 'Maybe[Net::Stripe::Plan|Str]');
 has 'coupon'      => (is => 'rw', isa => 'Maybe[Net::Stripe::Coupon|Str]');
 has 'discount'    => (is => 'rw', isa => 'Maybe[Net::Stripe::Discount]');
 has 'metadata'    => (is => 'rw', isa => 'Maybe[HashRef]');
-has 'account_balance' => (is => 'ro', isa => 'Maybe[Int]', default => 0);
+has 'account_balance' => (is => 'rw', isa => 'Maybe[Int]', trigger => \&_account_balance_trigger);
+has 'balance'     => (is => 'rw', isa => 'Maybe[Int]', trigger => \&_balance_trigger);
 has 'default_card' => (is => 'rw', isa => 'Maybe[Net::Stripe::Token|Net::Stripe::Card|Str]');
 has 'default_source' => (is => 'rw', isa => 'Maybe[StripeCardId|StripeSourceId]');
 
@@ -43,9 +44,33 @@ sub _build_subscription {
     return $self->subscriptions->get(0);
 }
 
+method _account_balance_trigger(
+    Maybe[Int] $new_value!,
+    Maybe[Int] $old_value?,
+) {
+    return unless defined( $new_value );
+    return if defined( $old_value ) && $old_value eq $new_value;
+    return if defined( $self->balance ) && $self->balance == $new_value;
+    $self->balance( $new_value );
+}
+
+method _balance_trigger(
+    Maybe[Int] $new_value!,
+    Maybe[Int] $old_value?,
+) {
+    return unless defined( $new_value );
+    return if defined( $old_value ) && $old_value eq $new_value;
+    return if defined( $self->account_balance ) && $self->account_balance == $new_value;
+    $self->account_balance( $new_value );
+}
+
 method form_fields {
+    $self->account_balance( undef ) if
+        defined( $self->account_balance ) &&
+        defined( $self->balance ) &&
+        $self->account_balance == $self->balance;
     return $self->form_fields_for(
-        qw/email description trial_end account_balance quantity card plan coupon
+        qw/email description trial_end account_balance balance quantity card plan coupon
             metadata default_card source default_source/
     );
 }
@@ -63,7 +88,7 @@ Net::Stripe::Customer - represent a Customer object from Stripe
 
 =head1 VERSION
 
-version 0.40_002
+version 0.40_003
 
 =head1 ATTRIBUTES
 
@@ -71,6 +96,16 @@ version 0.40_002
 
 Reader: account_balance
 
+Writer: account_balance
+
+Type: Maybe[Int]
+
+=head2 balance
+
+Reader: balance
+
+Writer: balance
+
 Type: Maybe[Int]
 
 =head2 boolean_attributes
