@@ -1,7 +1,7 @@
 package Net::Stripe::Invoice;
-$Net::Stripe::Invoice::VERSION = '0.40_002'; # TRIAL
+$Net::Stripe::Invoice::VERSION = '0.40_003'; # TRIAL
 
-$Net::Stripe::Invoice::VERSION = '0.40002';use Moose;
+$Net::Stripe::Invoice::VERSION = '0.40003';use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
 
@@ -13,9 +13,10 @@ has 'subtotal'      => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
 has 'amount_due'    => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
 has 'attempt_count' => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
 has 'attempted'     => ( is => 'ro', isa => 'Maybe[Bool|Object]', required => 1 );
-has 'closed'        => ( is => 'ro', isa => 'Maybe[Bool|Object]', required => 1, trigger => \&_closed_change_detector);
-has 'customer'      => ( is => 'ro', isa => 'Maybe[Str]', required => 1 );
-has 'date'          => ( is => 'ro', isa => 'Maybe[Str]', required => 1 );
+has 'closed'        => ( is => 'ro', isa => 'Maybe[Bool|Object]', trigger => \&_closed_change_detector);
+has 'auto_advance'  => ( is => 'ro', isa => 'Maybe[Bool]');
+has 'created'       => ( is => 'ro', isa => 'Maybe[Int]' );
+has 'date'          => ( is => 'ro', isa => 'Maybe[Str]' );
 has 'lines'         => ( is => 'ro', isa => 'Net::Stripe::List', required => 1 );
 has 'paid'          => ( is => 'ro', isa => 'Maybe[Bool|Object]', required => 1 );
 has 'period_end'    => ( is => 'ro', isa => 'Maybe[Int]' );
@@ -42,7 +43,7 @@ sub _closed_change_detector {
 
 method form_fields {
     return $self->form_fields_for(
-        qw/description metadata/,
+        qw/description metadata auto_advance/,
         ($self->{closed_value_changed} ? qw/closed/ : ())
     );
 }
@@ -60,7 +61,7 @@ Net::Stripe::Invoice - represent an Invoice object from Stripe
 
 =head1 VERSION
 
-version 0.40_002
+version 0.40_003
 
 =head1 ATTRIBUTES
 
@@ -88,6 +89,12 @@ Type: Maybe[Bool|Object]
 
 This attribute is required.
 
+=head2 auto_advance
+
+Reader: auto_advance
+
+Type: Maybe[Bool]
+
 =head2 boolean_attributes
 
 Reader: boolean_attributes
@@ -106,30 +113,18 @@ Reader: closed
 
 Type: Maybe[Bool|Object]
 
-This attribute is required.
-
 =head2 created
 
 Reader: created
 
 Type: Maybe[Int]
 
-=head2 customer
-
-Reader: customer
-
-Type: Maybe[Str]
-
-This attribute is required.
-
 =head2 date
 
 Reader: date
 
 Type: Maybe[Str]
 
-This attribute is required.
-
 =head2 description
 
 Reader: description
