@@ -1,7 +1,7 @@
 package Net::Stripe::List;
-$Net::Stripe::List::VERSION = '0.40_002'; # TRIAL
+$Net::Stripe::List::VERSION = '0.40_003'; # TRIAL
 
-$Net::Stripe::List::VERSION = '0.40002';use Moose;
+$Net::Stripe::List::VERSION = '0.40003';use Moose;
 use Kavorka;
 
 # ABSTRACT: represent a list of objects from Stripe
@@ -28,6 +28,32 @@ method last {
     return $self->get(scalar($self->elements)-1);
 }
 
+method _next_page_args() {
+    return (
+        starting_after => $self->get(-1)->id,
+    );
+}
+
+method _previous_page_args() {
+    return (
+        ending_before => $self->get(0)->id,
+    );
+}
+
+fun _merge_lists(
+    ArrayRef[Net::Stripe::List] :$lists!,
+) {
+    my $has_count = defined( $lists->[-1]->count );
+    my $url = $lists->[-1]->url;
+    my %list_args = (
+        count => $has_count ? scalar( map { $_->elements } @$lists ) : undef,
+        data => [ map { $_->elements } @$lists ],
+        has_more => 0,
+        url => $url,
+    );
+    return Net::Stripe::List->new( %list_args );
+}
+
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -41,7 +67,7 @@ Net::Stripe::List - represent a list of objects from Stripe
 
 =head1 VERSION
 
-version 0.40_002
+version 0.40_003
 
 =head1 ATTRIBUTES
 
