@@ -1,7 +1,7 @@
 package Net::Stripe::Plan;
-$Net::Stripe::Plan::VERSION = '0.40_002'; # TRIAL
+$Net::Stripe::Plan::VERSION = '0.40_003'; # TRIAL
 
-$Net::Stripe::Plan::VERSION = '0.40002';use Moose;
+$Net::Stripe::Plan::VERSION = '0.40003';use Moose;
 use Moose::Util::TypeConstraints qw(subtype as where message);
 use Kavorka;
 extends 'Net::Stripe::Resource';
@@ -18,15 +18,16 @@ has 'amount'            => (is => 'ro', isa => 'Maybe[Int]', required => 1);
 has 'currency'          => (is => 'ro', isa => 'Maybe[Str]', required => 1);
 has 'interval'          => (is => 'ro', isa => 'Maybe[Str]', required => 1);
 has 'interval_count'    => (is => 'ro', isa => 'Maybe[Int]', required => 0);
-has 'name'              => (is => 'ro', isa => 'Maybe[Str]', required => 1);
+has 'name'              => (is => 'ro', isa => 'Maybe[Str]');
 has 'trial_period_days' => (is => 'ro', isa => 'Maybe[Int]');
 has 'statement_descriptor' => (is => 'ro', isa => 'Maybe[StatementDescriptor]', required => 0);
 has 'metadata'          => (is => 'ro', isa => 'Maybe[HashRef]');
+has 'product'           => (is => 'ro', isa => 'Maybe[StripeProductId|Str]');
 
 method form_fields {
     return $self->form_fields_for(
         qw/id amount currency interval interval_count name statement_descriptor
-            trial_period_days metadata/
+            trial_period_days metadata product/
     );
 }
 
@@ -43,7 +44,7 @@ Net::Stripe::Plan - represent a Plan object from Stripe
 
 =head1 VERSION
 
-version 0.40_002
+version 0.40_003
 
 =head1 ATTRIBUTES
 
@@ -103,7 +104,11 @@ Reader: name
 
 Type: Maybe[Str]
 
-This attribute is required.
+=head2 product
+
+Reader: product
+
+Type: Maybe[Str|StripeProductId]
 
 =head2 statement_descriptor
 
