@@ -1,7 +1,7 @@
 package Net::Stripe::Resource;
-$Net::Stripe::Resource::VERSION = '0.40_002'; # TRIAL
+$Net::Stripe::Resource::VERSION = '0.40_003'; # TRIAL
 
-$Net::Stripe::Resource::VERSION = '0.40002';# ABSTRACT: represent a Resource object from Stripe
+$Net::Stripe::Resource::VERSION = '0.40003';# ABSTRACT: represent a Resource object from Stripe
 
 use Moose;
 use Kavorka;
@@ -82,6 +82,14 @@ fun form_fields_for_hashref (
     return @field_values;
 }
 
+fun form_fields_for_arrayref (
+    Str $field_name!,
+    ArrayRef $arrayref!,
+) {
+    my $nested_field_name = sprintf( '%s[]', $field_name );
+    return $nested_field_name => $arrayref;
+}
+
 method fields_for($for) {
     return unless $self->can($for);
     my $thingy = $self->$for;
@@ -90,6 +98,7 @@ method fields_for($for) {
     return ($for => $thingy->id) if $for eq 'source' && ref($thingy) eq 'Net::Stripe::Token';
     return $thingy->form_fields if ref($thingy) =~ m/^Net::Stripe::/;
     return form_fields_for_hashref( $for, $thingy ) if ref( $thingy ) eq 'HASH';
+    return form_fields_for_arrayref( $for, $thingy ) if ref( $thingy ) eq 'ARRAY';
     return ( $for => $self->get_form_field_value( $for ) );
 }
 
@@ -120,7 +129,7 @@ Net::Stripe::Resource - represent a Resource object from Stripe
 
 =head1 VERSION
 
-version 0.40_002
+version 0.40_003
 
 =head1 ATTRIBUTES
 
