@@ -1,7 +1,7 @@
 package Net::Stripe::TypeConstraints;
-$Net::Stripe::TypeConstraints::VERSION = '0.40_002'; # TRIAL
+$Net::Stripe::TypeConstraints::VERSION = '0.40_003'; # TRIAL
 
-$Net::Stripe::TypeConstraints::VERSION = '0.40002';use strict;
+$Net::Stripe::TypeConstraints::VERSION = '0.40003';use strict;
 use Moose::Util::TypeConstraints qw/subtype as where message enum/;
 
 # ABSTRACT: Custom Moose TypeConstraints for Net::Stripe object attributes and parameters
@@ -69,6 +69,17 @@ subtype 'EmptyStr',
         sprintf( "Value '%s' must be an empty string", $_ );
     };
 
+subtype 'StripeProductId',
+    as 'Str',
+    where {
+        /^prod_.+/
+    },
+    message {
+        sprintf( "Value '%s' must be a product id string of the form prod_.+", $_ );
+    };
+
+enum 'StripeProductType' => [qw/ good service /];
+
 1;
 
 __END__
@@ -81,7 +92,7 @@ Net::Stripe::TypeConstraints - Custom Moose TypeConstraints for Net::Stripe obje
 
 =head1 VERSION
 
-version 0.40_002
+version 0.40_003
 
 =head1 AUTHORS
 
